@@ -3,7 +3,7 @@ extern crate criterion;
 
 use criterion::{black_box, Criterion};
 use std::time::{Duration, Instant};
-use tch::kind::Kind::Float;
+use tch::kind::Kind;
 use tch::{Device, Tensor};
 
 fn matrix_multiply(iters: u64, input: &Tensor, weights: &Tensor) -> Duration {
@@ -21,8 +21,8 @@ fn bench_tensor_ops(c: &mut Criterion) {
     unsafe {
         torch_sys::dummy_cuda_dependency();
     }
-    let input = Tensor::rand(&[32, 128, 512], (Float, Device::cuda_if_available()));
-    let weights = Tensor::rand(&[512, 512], (Float, Device::cuda_if_available()));
+    let input = Tensor::rand(&[32, 128, 512], (Kind::Float, Device::cuda_if_available()));
+    let weights = Tensor::rand(&[512, 512], (Kind::Float, Device::cuda_if_available()));
 
     let _ = &input.matmul(&weights);
     c.bench_function("Matrix multiply ", |b| {
