@@ -205,8 +205,6 @@ impl BartEncoder {
         embeddings: &nn::Embedding,
         train: bool,
     ) -> BartEncoderOutput {
-        let attention_mask = attention_mask.map(|mask| _expand_mask(mask, None));
-
         let x = input_ids.apply(embeddings) * self.scale_embedding;
         let x: Tensor = x + &self.embed_positions.forward(input_ids, 0);
         let x = if let Some(layer_norm_embedding) = &self.layer_norm_embedding {
@@ -214,6 +212,7 @@ impl BartEncoder {
         } else {
             x
         };
+        let attention_mask = attention_mask.map(|mask| _expand_mask(mask, None, x.kind()));
         let mut hidden_state = x.apply_t(&self.dropout, train);
 
         let mut all_hidden_states: Option<Vec<Tensor>> = if self.output_hidden_states {
