@@ -12,6 +12,7 @@
 
 use crate::common::activations::{TensorFunction, _tanh};
 use crate::common::dropout::Dropout;
+use crate::common::embeddings::get_shape_and_device_from_ids_embeddings_pair;
 use crate::longformer::embeddings::LongformerEmbeddings;
 use crate::longformer::encoder::LongformerEncoder;
 use crate::{Activation, Config, RustBertError};
@@ -34,12 +35,12 @@ pub struct LongformerVocabResources;
 pub struct LongformerMergesResources;
 
 impl LongformerModelResources {
-    /// Shared under Apache 2.0 license by the AllenAI team at https://github.com/allenai/longformer. Modified with conversion to C-array format.
+    /// Shared under Apache 2.0 license by the AllenAI team at <https://github.com/allenai/longformer>. Modified with conversion to C-array format.
     pub const LONGFORMER_BASE_4096: (&'static str, &'static str) = (
         "longformer-base-4096/model",
         "https://huggingface.co/allenai/longformer-base-4096/resolve/main/rust_model.ot",
     );
-    /// Shared under MIT license at https://huggingface.co/valhalla/longformer-base-4096-finetuned-squadv1. Modified with conversion to C-array format.
+    /// Shared under MIT license at <https://huggingface.co/valhalla/longformer-base-4096-finetuned-squadv1>. Modified with conversion to C-array format.
     pub const LONGFORMER_BASE_SQUAD1: (&'static str, &'static str) = (
         "longformer-base-4096/model",
         "https://huggingface.co/valhalla/longformer-base-4096-finetuned-squadv1/resolve/main/rust_model.ot",
@@ -47,12 +48,12 @@ impl LongformerModelResources {
 }
 
 impl LongformerConfigResources {
-    /// Shared under Apache 2.0 license by the AllenAI team at https://github.com/allenai/longformer. Modified with conversion to C-array format.
+    /// Shared under Apache 2.0 license by the AllenAI team at <https://github.com/allenai/longformer>. Modified with conversion to C-array format.
     pub const LONGFORMER_BASE_4096: (&'static str, &'static str) = (
         "longformer-base-4096/config",
         "https://huggingface.co/allenai/longformer-base-4096/resolve/main/config.json",
     );
-    /// Shared under MIT license at https://huggingface.co/valhalla/longformer-base-4096-finetuned-squadv1. Modified with conversion to C-array format.
+    /// Shared under MIT license at <https://huggingface.co/valhalla/longformer-base-4096-finetuned-squadv1>. Modified with conversion to C-array format.
     pub const LONGFORMER_BASE_SQUAD1: (&'static str, &'static str) = (
         "longformer-base-4096/config",
         "https://huggingface.co/valhalla/longformer-base-4096-finetuned-squadv1/resolve/main/config.json",
@@ -60,12 +61,12 @@ impl LongformerConfigResources {
 }
 
 impl LongformerVocabResources {
-    /// Shared under Apache 2.0 license by the AllenAI team at https://github.com/allenai/longformer. Modified with conversion to C-array format.
+    /// Shared under Apache 2.0 license by the AllenAI team at <https://github.com/allenai/longformer>. Modified with conversion to C-array format.
     pub const LONGFORMER_BASE_4096: (&'static str, &'static str) = (
         "longformer-base-4096/vocab",
         "https://huggingface.co/allenai/longformer-base-4096/resolve/main/vocab.json",
     );
-    /// Shared under MIT license at https://huggingface.co/valhalla/longformer-base-4096-finetuned-squadv1. Modified with conversion to C-array format.
+    /// Shared under MIT license at <https://huggingface.co/valhalla/longformer-base-4096-finetuned-squadv1>. Modified with conversion to C-array format.
     pub const LONGFORMER_BASE_SQUAD1: (&'static str, &'static str) = (
         "longformer-base-4096/vocab",
         "https://huggingface.co/valhalla/longformer-base-4096-finetuned-squadv1/resolve/main/vocab.json",
@@ -73,12 +74,12 @@ impl LongformerVocabResources {
 }
 
 impl LongformerMergesResources {
-    /// Shared under Apache 2.0 license by the AllenAI team at https://github.com/allenai/longformer. Modified with conversion to C-array format.
+    /// Shared under Apache 2.0 license by the AllenAI team at <https://github.com/allenai/longformer>. Modified with conversion to C-array format.
     pub const LONGFORMER_BASE_4096: (&'static str, &'static str) = (
         "longformer-base-4096/merges",
         "https://huggingface.co/allenai/longformer-base-4096/resolve/main/merges.txt",
     );
-    /// Shared under MIT license at https://huggingface.co/valhalla/longformer-base-4096-finetuned-squadv1. Modified with conversion to C-array format.
+    /// Shared under MIT license at <https://huggingface.co/valhalla/longformer-base-4096-finetuned-squadv1>. Modified with conversion to C-array format.
     pub const LONGFORMER_BASE_SQUAD1: (&'static str, &'static str) = (
         "longformer-base-4096/merges",
         "https://huggingface.co/valhalla/longformer-base-4096-finetuned-squadv1/resolve/main/merges.txt",
@@ -120,7 +121,7 @@ pub struct LongformerConfig {
     pub label2id: Option<HashMap<String, i64>>,
 }
 
-impl Config<LongformerConfig> for LongformerConfig {}
+impl Config for LongformerConfig {}
 
 fn get_question_end_index(input_ids: &Tensor, sep_token_id: i64) -> Tensor {
     input_ids
@@ -140,11 +141,13 @@ fn compute_global_attention_mask(
     let attention_mask = Tensor::arange(input_ids.size()[1], (Kind::Int64, input_ids.device()));
 
     if before_sep_token {
-        attention_mask.expand_as(input_ids).lt1(&question_end_index)
+        attention_mask
+            .expand_as(input_ids)
+            .lt_tensor(&question_end_index)
     } else {
         attention_mask
             .expand_as(input_ids)
-            .gt1(&(question_end_index + 1))
+            .gt_tensor(&(question_end_index + 1))
             * attention_mask
                 .expand_as(input_ids)
                 .lt(*input_ids.size().last().unwrap())
@@ -352,21 +355,8 @@ impl LongformerModel {
         padding_length: i64,
         train: bool,
     ) -> Result<PaddedInput, RustBertError> {
-        let input_shape = if let Some(input_ids) = input_ids {
-            if input_embeds.is_none() {
-                input_ids.size()
-            } else {
-                return Err(RustBertError::ValueError(
-                    "Only one of input ids or input embeddings may be set".into(),
-                ));
-            }
-        } else if let Some(input_embeds) = input_embeds {
-            input_embeds.size()[..2].to_vec()
-        } else {
-            return Err(RustBertError::ValueError(
-                "At least one of input ids or input embeddings must be set".into(),
-            ));
-        };
+        let (input_shape, _) =
+            get_shape_and_device_from_ids_embeddings_pair(input_ids, input_embeds)?;
         let batch_size = input_shape[0];
 
         let input_ids = input_ids
@@ -388,7 +378,7 @@ impl LongformerModel {
         });
 
         let attention_mask =
-            attention_mask.map(|value| self.pad_with_boolean(&value, &[0, padding_length], false));
+            attention_mask.map(|value| self.pad_with_boolean(value, &[0, padding_length], false));
         let token_type_ids =
             token_type_ids.map(|value| value.constant_pad_nd(&[0, padding_length]));
         Ok(PaddedInput {
@@ -465,21 +455,8 @@ impl LongformerModel {
         input_embeds: Option<&Tensor>,
         train: bool,
     ) -> Result<LongformerModelOutput, RustBertError> {
-        let (input_shape, device) = if let Some(input_ids) = input_ids {
-            if input_embeds.is_none() {
-                (input_ids.size(), input_ids.device())
-            } else {
-                return Err(RustBertError::ValueError(
-                    "Only one of input ids or input embeddings may be set".into(),
-                ));
-            }
-        } else if let Some(input_embeds) = input_embeds {
-            (input_embeds.size()[..2].to_vec(), input_embeds.device())
-        } else {
-            return Err(RustBertError::ValueError(
-                "At least one of input ids or input embeddings must be set".into(),
-            ));
-        };
+        let (input_shape, device) =
+            get_shape_and_device_from_ids_embeddings_pair(input_ids, input_embeds)?;
 
         let (batch_size, sequence_length) = (input_shape[0], input_shape[1]);
 
@@ -580,7 +557,7 @@ impl LongformerModel {
                         .unsqueeze(0)
                         .unsqueeze(0)
                         .repeat(&[batch_size, sequence_length, 1])
-                        .le1(&sequence_ids.unsqueeze(-1).unsqueeze(0))
+                        .le_tensor(&sequence_ids.unsqueeze(-1).unsqueeze(0))
                         .totype(Kind::Int);
                     if causal_mask.size()[1] < padded_attention_mask.size()[1] {
                         let prefix_sequence_length =
@@ -1147,8 +1124,8 @@ impl LongformerForQuestionAnswering {
         let sequence_output = base_model_output.hidden_state.apply(&self.qa_outputs);
         let logits = sequence_output.split(1, -1);
         let (start_logits, end_logits) = (&logits[0], &logits[1]);
-        let start_logits = start_logits.squeeze1(-1);
-        let end_logits = end_logits.squeeze1(-1);
+        let start_logits = start_logits.squeeze_dim(-1);
+        let end_logits = end_logits.squeeze_dim(-1);
 
         Ok(LongformerQuestionAnsweringOutput {
             start_logits,
