@@ -90,9 +90,10 @@ use crate::pipelines::token_classification::{
     LabelAggregationOption, TokenClassificationConfig, TokenClassificationModel,
 };
 use crate::resources::{RemoteResource, Resource};
+use serde::{Deserialize, Serialize};
 use tch::Device;
 
-#[derive(Debug)]
+#[derive(Debug, Serialize, Deserialize)]
 /// # Part of Speech tag
 pub struct POSTag {
     /// String representation of the word
@@ -195,9 +196,9 @@ impl POSModel {
     /// # Ok(())
     /// # }
     /// ```
-    pub fn predict<'a, S>(&self, input: S) -> Vec<Vec<POSTag>>
+    pub fn predict<S>(&self, input: &[S]) -> Vec<Vec<POSTag>>
     where
-        S: AsRef<[&'a str]>,
+        S: AsRef<str>,
     {
         self.token_classification_model
             .predict(input, true, false)
