@@ -51,6 +51,7 @@ use crate::distilbert::{
     DistilBertConfigResources, DistilBertForQuestionAnswering, DistilBertModelResources,
     DistilBertVocabResources,
 };
+use crate::fnet::FNetForQuestionAnswering;
 use crate::longformer::LongformerForQuestionAnswering;
 use crate::mobilebert::MobileBertForQuestionAnswering;
 use crate::pipelines::common::{ConfigOption, ModelType, TokenizerOption};
@@ -58,6 +59,7 @@ use crate::reformer::ReformerForQuestionAnswering;
 use crate::roberta::RobertaForQuestionAnswering;
 use crate::xlnet::XLNetForQuestionAnswering;
 use rust_tokenizers::{Offset, TokenIdsWithOffsets, TokenizedInput};
+use serde::{Deserialize, Serialize};
 use std::borrow::Borrow;
 use std::cmp::min;
 use std::collections::HashMap;
@@ -67,6 +69,7 @@ use tch::kind::Kind::Float;
 use tch::nn::VarStore;
 use tch::{nn, no_grad, Device, Tensor};
 
+#[derive(Serialize, Deserialize)]
 /// # Input for Question Answering
 /// Includes a context (containing the answer) and question strings
 pub struct QaInput {
@@ -84,7 +87,7 @@ struct QaFeature {
     pub example_index: i64,
 }
 
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Serialize, Deserialize)]
 /// # Output for Question Answering
 pub struct Answer {
     /// Confidence score
@@ -277,6 +280,8 @@ pub enum QuestionAnsweringOption {
     Reformer(ReformerForQuestionAnswering),
     /// Longformer for Question Answering
     Longformer(LongformerForQuestionAnswering),
+    /// FNet for Question Answering
+    FNet(FNetForQuestionAnswering),
 }
 
 impl QuestionAnsweringOption {
@@ -396,6 +401,17 @@ impl QuestionAnsweringOption {
                     ))
                 }
             }
+            ModelType::FNet => {
+                if let ConfigOption::FNet(config) = config {
+                    Ok(QuestionAnsweringOption::FNet(
+                        FNetForQuestionAnswering::new(p, config),
+                    ))
+                } else {
+                    Err(RustBertError::InvalidConfigurationError(
+                        "You can only supply a FNetConfig for FNet!".to_string(),
+                    ))
+                }
+            }
             _ => Err(RustBertError::InvalidConfigurationError(format!(
                 "QuestionAnswering not implemented for {:?}!",
                 model_type
@@ -415,6 +431,7 @@ impl QuestionAnsweringOption {
             Self::XLNet(_) => ModelType::XLNet,
             Self::Reformer(_) => ModelType::Reformer,
             Self::Longformer(_) => ModelType::Longformer,
+            Self::FNet(_) => ModelType::FNet,
         }
     }
 
@@ -468,6 +485,12 @@ impl QuestionAnsweringOption {
                     .expect("Error in reformer forward pass");
                 (outputs.start_logits, outputs.end_logits)
             }
+            Self::FNet(ref model) => {
+                let outputs = model
+                    .forward_t(input_ids, None, None, None, train)
+                    .expect("Error in fnet forward pass");
+                (outputs.start_logits, outputs.end_logits)
+            }
         }
     }
 }
