@@ -118,6 +118,7 @@ use crate::common::error::RustBertError;
 use crate::common::resources::{RemoteResource, Resource};
 use crate::distilbert::DistilBertForTokenClassification;
 use crate::electra::ElectraForTokenClassification;
+use crate::fnet::FNetForTokenClassification;
 use crate::longformer::LongformerForTokenClassification;
 use crate::mobilebert::MobileBertForTokenClassification;
 use crate::pipelines::common::{ConfigOption, ModelType, TokenizerOption};
@@ -317,6 +318,8 @@ pub enum TokenClassificationOption {
     XLNet(XLNetForTokenClassification),
     /// Longformer for Token Classification
     Longformer(LongformerForTokenClassification),
+    /// FNet for Token Classification
+    FNet(FNetForTokenClassification),
 }
 
 impl TokenClassificationOption {
@@ -436,6 +439,17 @@ impl TokenClassificationOption {
                     ))
                 }
             }
+            ModelType::FNet => {
+                if let ConfigOption::FNet(config) = config {
+                    Ok(TokenClassificationOption::FNet(
+                        FNetForTokenClassification::new(p, config),
+                    ))
+                } else {
+                    Err(RustBertError::InvalidConfigurationError(
+                        "You can only supply an FNetConfig for FNet!".to_string(),
+                    ))
+                }
+            }
             _ => Err(RustBertError::InvalidConfigurationError(format!(
                 "Token classification not implemented for {:?}!",
                 model_type
@@ -455,6 +469,7 @@ impl TokenClassificationOption {
             Self::Albert(_) => ModelType::Albert,
             Self::XLNet(_) => ModelType::XLNet,
             Self::Longformer(_) => ModelType::Longformer,
+            Self::FNet(_) => ModelType::FNet,
         }
     }
 
@@ -556,6 +571,12 @@ impl TokenClassificationOption {
                     .expect("Error in longformer forward_t")
                     .logits
             }
+            Self::FNet(ref model) => {
+                model
+                    .forward_t(input_ids, token_type_ids, position_ids, input_embeds, train)
+                    .expect("Error in fnet forward_t")
+                    .logits
+            }
         }
     }
 }
@@ -776,17 +797,16 @@ impl TokenClassificationModel {
     /// # Ok(())
     /// # }
     /// ```
-    pub fn predict<'a, S>(
+    pub fn predict<S>(
         &self,
-        input: S,
+        input: &[S],
         consolidate_sub_tokens: bool,
         return_special: bool,
     ) -> Vec<Vec<Token>>
     where
-        S: AsRef<[&'a str]>,
+        S: AsRef<str>,
     {
         let mut features: Vec<InputFeature> = input
-            .as_ref()
             .iter()
             .enumerate()
             .map(|(example_index, example)| self.generate_features(example, example_index))
@@ -794,7 +814,7 @@ impl TokenClassificationModel {
             .collect();
 
         let mut example_tokens_map: HashMap<usize, Vec<Token>> = HashMap::new();
-        for example_idx in 0..input.as_ref().len() {
+        for example_idx in 0..input.len() {
             example_tokens_map.insert(example_idx, Vec::new());
         }
         let mut start = 0usize;
@@ -820,7 +840,8 @@ impl TokenClassificationModel {
                     let labels = label_indices.get(sentence_idx);
                     let feature = &features[sentence_idx as usize];
                     let sentence_reference_flag = &feature.reference_feature;
-                    let original_chars = input.as_ref()[feature.example_index]
+                    let original_chars = input[feature.example_index]
+                        .as_ref()
                         .chars()
                         .collect::<Vec<char>>();
                     let mut word_idx: u16 = 0;
@@ -935,19 +956,19 @@ impl TokenClassificationModel {
         let text = match offsets {
             None => match self.tokenizer {
                 TokenizerOption::Bert(ref tokenizer) => {
-                    Tokenizer::decode(tokenizer, vec![token_id], false, false)
+                    Tokenizer::decode(tokenizer, &[token_id], false, false)
                 }
                 TokenizerOption::Roberta(ref tokenizer) => {
-                    Tokenizer::decode(tokenizer, vec![token_id], false, false)
+                    Tokenizer::decode(tokenizer, &[token_id], false, false)
                 }
                 TokenizerOption::XLMRoberta(ref tokenizer) => {
-                    Tokenizer::decode(tokenizer, vec![token_id], false, false)
+                    Tokenizer::decode(tokenizer, &[token_id], false, false)
                 }
                 TokenizerOption::Albert(ref tokenizer) => {
-                    Tokenizer::decode(tokenizer, vec![token_id], false, false)
+                    Tokenizer::decode(tokenizer, &[token_id], false, false)
                 }
                 TokenizerOption::XLNet(ref tokenizer) => {
-                    Tokenizer::decode(tokenizer, vec![token_id], false, false)
+                    Tokenizer::decode(tokenizer, &[token_id], false, false)
                 }
                 _ => panic!(
                     "Token classification not implemented for {:?}!",
