@@ -364,7 +364,7 @@ impl TranslationModelBuilder {
             {
                 match (source_languages.as_slice(), target_languages.as_slice()) {
                     ([Language::English], [Language::German]) => {
-                        get_marian_resources!(ENGLISH2RUSSIAN)
+                        get_marian_resources!(ENGLISH2GERMAN)
                     }
                     ([Language::English], [Language::Russian]) => {
                         get_marian_resources!(ENGLISH2RUSSIAN)
@@ -390,6 +390,12 @@ impl TranslationModelBuilder {
                     ([Language::German], [Language::English]) => {
                         get_marian_resources!(GERMAN2ENGLISH)
                     }
+                    ([Language::German], [Language::French]) => {
+                        get_marian_resources!(GERMAN2FRENCH)
+                    }
+                    ([Language::French], [Language::German]) => {
+                        get_marian_resources!(FRENCH2GERMAN)
+                    }
                     ([Language::Russian], [Language::English]) => {
                         get_marian_resources!(RUSSIAN2ENGLISH)
                     }
