@@ -12,6 +12,7 @@
 
 use crate::common::dropout::Dropout;
 use crate::common::embeddings::process_ids_embeddings_pair;
+use crate::common::kind::get_negative_infinity;
 use crate::prophetnet::attention::{
     compute_all_stream_relative_buckets, LayerState, ProphetNetAttention, ProphetNetFeedForward,
     ProphetNetNgramAttention,
@@ -23,11 +24,9 @@ use std::borrow::{Borrow, BorrowMut};
 use tch::nn::Init;
 use tch::{nn, Device, Kind, Tensor};
 
-fn ngram_attention_bias(sequence_length: i64, ngram: i64, device: Device) -> Tensor {
-    let left_block = Tensor::ones(
-        &[ngram, sequence_length, sequence_length],
-        (Kind::Float, device),
-    ) * f64::NEG_INFINITY;
+fn ngram_attention_bias(sequence_length: i64, ngram: i64, device: Device, kind: Kind) -> Tensor {
+    let left_block = Tensor::ones(&[ngram, sequence_length, sequence_length], (kind, device))
+        * get_negative_infinity(kind).unwrap();
     let right_block = left_block.copy();
     for stream_idx in 0..ngram {
         let _ = right_block.get(stream_idx).fill_diagonal_(0, false);
@@ -516,8 +515,8 @@ impl ProphetNetDecoder {
 
         let causal_mask = Tensor::full(
             &[sequence_length, sequence_length],
-            f64::NEG_INFINITY,
-            (Kind::Float, hidden_states.device()),
+            get_negative_infinity(hidden_states.kind()).unwrap(),
+            (hidden_states.kind(), hidden_states.device()),
         )
         .triu_(1);
 
@@ -527,7 +526,8 @@ impl ProphetNetDecoder {
 
         let extended_attention_mask = if let Some(attention_mask_value) = attention_mask {
             let extended_attention_mask =
-                (attention_mask_value.ones_like() - attention_mask_value.unsqueeze(1)) * -10000.0;
+                ((attention_mask_value.ones_like() - attention_mask_value.unsqueeze(1)) * -10000.0)
+                    .to_kind(causal_mask.kind());
             extended_causal_mask + extended_attention_mask
         } else {
             extended_causal_mask
@@ -548,6 +548,7 @@ impl ProphetNetDecoder {
             self.max_target_positions,
             self.ngram,
             hidden_states.device(),
+            hidden_states.kind(),
         );
 
         let predict_causal_mask = Tensor::cat(
