@@ -49,7 +49,6 @@ pub struct T5Attention {
     is_bidirectional: bool,
     has_relative_attention_bias: bool,
     relative_attention_num_buckets: i64,
-    d_model: i64,
     d_kv: i64,
     n_heads: i64,
     dropout: Dropout,
@@ -106,7 +105,6 @@ impl T5Attention {
             is_bidirectional,
             has_relative_attention_bias,
             relative_attention_num_buckets: config.relative_attention_num_buckets,
-            d_model: config.d_model,
             d_kv: config.d_kv,
             n_heads: config.num_heads,
             dropout,
@@ -224,7 +222,7 @@ impl T5Attention {
         scores += position_bias;
 
         let attention_weights = scores
-            .softmax(-1, Kind::Float)
+            .softmax(-1, scores.kind())
             .apply_t(&self.dropout, train);
         let context = self
             .unshape(attention_weights.matmul(&v), bs)
