@@ -7,7 +7,7 @@ use rust_bert::pipelines::conversation::{
     ConversationConfig, ConversationManager, ConversationModel,
 };
 use rust_bert::pipelines::generation_utils::{
-    Cache, GenerateConfig, LMHeadModel, LanguageGenerator,
+    Cache, GenerateConfig, GenerateOptions, LMHeadModel, LanguageGenerator,
 };
 use rust_bert::pipelines::text_generation::{TextGenerationConfig, TextGenerationModel};
 use rust_bert::resources::{RemoteResource, Resource};
@@ -82,7 +82,7 @@ fn gpt2_lm_model() -> anyhow::Result<()> {
         .get(-1)
         .argmax(-1, true)
         .int64_value(&[0]);
-    let next_word = tokenizer.decode(vec![next_word_id], true, true);
+    let next_word = tokenizer.decode(&[next_word_id], true, true);
 
     assert_eq!(model_output.lm_logits.size(), vec!(1, 4, 50257));
     match model_output.cache {
@@ -420,15 +420,16 @@ fn gpt2_prefix_allowed_token_greedy() -> anyhow::Result<()> {
 
     let input_context_1 = "Rust is a";
     let input_context_2 = "There was a ";
+
+    let generate_options = GenerateOptions {
+        prefix_allowed_tokens_fn: Some(&force_one_paragraph),
+        output_scores: true,
+        ..Default::default()
+    };
+
     let output = model.generate(
         Some(&[input_context_1, input_context_2]),
-        None,
-        None,
-        None,
-        None,
-        None,
-        Some(&force_one_paragraph),
-        true,
+        Some(generate_options),
     );
 
     assert_eq!(output.len(), 2);
@@ -446,6 +447,146 @@ fn gpt2_prefix_allowed_token_greedy() -> anyhow::Result<()> {
     Ok(())
 }
 
+#[test]
+fn gpt2_bad_tokens_greedy() -> anyhow::Result<()> {
+    //    Resources definition
+    let config_resource =
+        Resource::Remote(RemoteResource::from_pretrained(Gpt2ConfigResources::GPT2));
+    let vocab_resource =
+        Resource::Remote(RemoteResource::from_pretrained(Gpt2VocabResources::GPT2));
+    let merges_resource =
+        Resource::Remote(RemoteResource::from_pretrained(Gpt2MergesResources::GPT2));
+    let model_resource =
+        Resource::Remote(RemoteResource::from_pretrained(Gpt2ModelResources::GPT2));
+
+    let generate_config = GenerateConfig {
+        max_length: 36,
+        model_resource,
+        config_resource,
+        vocab_resource,
+        merges_resource,
+        do_sample: false,
+        num_beams: 1,
+        device: Device::Cpu,
+        ..Default::default()
+    };
+    let model = GPT2Generator::new(generate_config)?;
+
+    let bad_words = vec![" honeybees", " a writer"];
+    let bad_word_ids = model
+        .get_tokenizer()
+        .encode_list(
+            bad_words.as_slice(),
+            512,
+            &TruncationStrategy::DoNotTruncate,
+            0,
+        )
+        .into_iter()
+        .map(|tokenized_input| tokenized_input.token_ids)
+        .collect::<Vec<Vec<i64>>>();
+
+    let input_context_1 = "Hello, my name is";
+
+    let baseline_generate_options = GenerateOptions {
+        output_scores: true,
+        ..Default::default()
+    };
+    let test_generate_options = GenerateOptions {
+        bad_word_ids: Some(&bad_word_ids),
+        output_scores: true,
+        ..Default::default()
+    };
+
+    let baseline_output = model.generate(Some(&[input_context_1]), Some(baseline_generate_options));
+    let output = model.generate(Some(&[input_context_1]), Some(test_generate_options));
+
+    assert_eq!(baseline_output.len(), 1);
+    assert_eq!(
+        baseline_output[0].text,
+        "Hello, my name is John. I'm a writer, and I'm writing a book. I've been writing for a long time. I was born in New York City,"
+    );
+    assert!((baseline_output[0].score.unwrap() - (-1.3316)).abs() < 1e-4);
+
+    assert_eq!(output.len(), 1);
+    assert_eq!(
+        output[0].text,
+        "Hello, my name is John. I'm a student at the University of California, Berkeley. I've been studying computer science for a year. I have a PhD in computer science"
+    );
+    assert!((output[0].score.unwrap() - (-1.2307)).abs() < 1e-4);
+
+    Ok(())
+}
+
+#[test]
+fn gpt2_bad_tokens_beam_search() -> anyhow::Result<()> {
+    //    Resources definition
+    let config_resource =
+        Resource::Remote(RemoteResource::from_pretrained(Gpt2ConfigResources::GPT2));
+    let vocab_resource =
+        Resource::Remote(RemoteResource::from_pretrained(Gpt2VocabResources::GPT2));
+    let merges_resource =
+        Resource::Remote(RemoteResource::from_pretrained(Gpt2MergesResources::GPT2));
+    let model_resource =
+        Resource::Remote(RemoteResource::from_pretrained(Gpt2ModelResources::GPT2));
+
+    let generate_config = GenerateConfig {
+        max_length: 36,
+        model_resource,
+        config_resource,
+        vocab_resource,
+        merges_resource,
+        do_sample: false,
+        num_beams: 3,
+        device: Device::Cpu,
+        ..Default::default()
+    };
+    let model = GPT2Generator::new(generate_config)?;
+
+    let bad_words = vec![" honeybees", " a member"];
+    let bad_word_ids = model
+        .get_tokenizer()
+        .encode_list(
+            bad_words.as_slice(),
+            512,
+            &TruncationStrategy::DoNotTruncate,
+            0,
+        )
+        .into_iter()
+        .map(|tokenized_input| tokenized_input.token_ids)
+        .collect::<Vec<Vec<i64>>>();
+
+    let input_context_1 = "Hello, my name is";
+
+    let baseline_generate_options = GenerateOptions {
+        output_scores: true,
+        ..Default::default()
+    };
+    let test_generate_options = GenerateOptions {
+        bad_word_ids: Some(&bad_word_ids),
+        output_scores: true,
+        ..Default::default()
+    };
+
+    let baseline_output = model.generate(Some(&[input_context_1]), Some(baseline_generate_options));
+    let output = model.generate(Some(&[input_context_1]), Some(test_generate_options));
+
+    assert_eq!(baseline_output.len(), 1);
+    assert_eq!(
+        baseline_output[0].text,
+        "Hello, my name is John, and I am a member of the Church of Jesus Christ of Latter-day Saints.\n\nI am a Mormon. I have been a member"
+    );
+    assert!((baseline_output[0].score.unwrap() - (-1.0503)).abs() < 1e-4);
+
+    assert_eq!(output.len(), 1);
+    assert_eq!(
+        output[0].text,
+        "Hello, my name is John, and I am the owner of a small business.\n\nI have been in business for over 20 years. I have been a business owner for"
+    );
+    assert!((output[0].score.unwrap() - (-1.3742)).abs() < 1e-4);
+
+    Ok(())
+}
+
 #[test]
 fn gpt2_prefix_allowed_token_beam_search() -> anyhow::Result<()> {
     //    Resources definition
@@ -488,15 +629,16 @@ fn gpt2_prefix_allowed_token_beam_search() -> anyhow::Result<()> {
 
     let input_context_1 = "Rust is a";
     let input_context_2 = "There was a ";
+
+    let generate_options = GenerateOptions {
+        prefix_allowed_tokens_fn: Some(&force_one_paragraph),
+        output_scores: true,
+        ..Default::default()
+    };
+
     let output = model.generate(
         Some(&[input_context_1, input_context_2]),
-        None,
-        None,
-        None,
-        None,
-        None,
-        Some(&force_one_paragraph),
-        true,
+        Some(generate_options),
     );
 
     assert_eq!(output.len(), 2);
