@@ -3,10 +3,12 @@ import numpy as np
 import torch
 import subprocess
 import argparse
+import sys
 
 if __name__ == "__main__":
     parser = argparse.ArgumentParser()
     parser.add_argument("source_file", help="Absolute path to the Pytorch weights file to convert")
+    parser.add_argument("--skip_embeddings", action="store_true", help="Skip shared embeddings / language model head")
     args = parser.parse_args()
 
     source_file = Path(args.source_file)
@@ -17,8 +19,11 @@ if __name__ == "__main__":
     nps = {}
     for k, v in weights.items():
         k = k.replace("gamma", "weight").replace("beta", "bias")
-        nps[k] = np.ascontiguousarray(v.cpu().numpy())
-
+        if args.skip_embeddings:
+            if k in {"lm_head.weight", "model.encoder.embed_tokens.weight", "model.decoder.embed_tokens.weight"}:
+                continue
+        nps[k] = np.ascontiguousarray(v.cpu().numpy().astype(np.float32))
+        print(f'converted {k} - {str(sys.getsizeof(nps[k]))} bytes')
     np.savez(target_folder / 'model.npz', **nps)
 
     source = str(target_folder / 'model.npz')
